@@ -25,6 +25,7 @@ from yellowdog_client.model import (
     MachineImage,
     MachineImageFamily,
     MachineImageGroup,
+    NamespacePolicy,
     NamespaceStorageConfiguration,
     RequirementsAllowance,
     SourceAllowance,
@@ -39,7 +40,7 @@ from yd_commands.load_resources import load_resource_specifications
 from yd_commands.object_utilities import (
     clear_compute_source_template_cache,
     clear_image_family_search_cache,
-    find_compute_requirement_template_ids_by_name,
+    find_compute_requirement_template_id_by_name,
     find_compute_source_template_id_by_name,
     find_image_family_ids_by_name,
     remove_allowances_matching_description,
@@ -51,6 +52,7 @@ from yd_commands.settings import (
     RN_CREDENTIAL,
     RN_IMAGE_FAMILY,
     RN_KEYRING,
+    RN_NAMESPACE_POLICY,
     RN_NUMERIC_ATTRIBUTE_DEFINITION,
     RN_REQUIREMENT_TEMPLATE,
     RN_SOURCE_TEMPLATE,
@@ -124,7 +126,9 @@ def create_resources(
                 RN_STRING_ATTRIBUTE_DEFINITION,
                 RN_NUMERIC_ATTRIBUTE_DEFINITION,
             ]:
-                create_attribute_definition_via_api(resource, resource_type)
+                create_attribute_definition(resource, resource_type)
+            elif resource_type == RN_NAMESPACE_POLICY:
+                create_namespace_policy(resource)
             else:
                 print_error(f"Unknown resource type '{resource_type}'")
         except Exception as e:
@@ -269,8 +273,9 @@ def create_compute_requirement_template(resource: Dict):
     compute_template = _get_model_object(type, resource)
 
     # Check for an existing ID
-    template_ids = find_compute_requirement_template_ids_by_name(CLIENT, name)
-    if len(template_ids) == 0:
+    template_id = find_compute_requirement_template_id_by_name(CLIENT, name)
+
+    if template_id is None:  # Creation
         template = CLIENT.compute_client.add_compute_requirement_template(
             compute_template
         )
@@ -279,28 +284,24 @@ def create_compute_requirement_template(resource: Dict):
         )
         if ARGS_PARSER.quiet:
             print(template.id)
-    else:
-        if len(template_ids) > 1:
-            print_warning(
-                f"{len(template_ids)} Compute Requirement Templates with the name"
-                f" '{name}'"
-            )
-        for template_id in template_ids:
-            compute_template.id = template_id
-            if not confirmed(
-                f"Update existing Compute Requirement Template '{name}'"
-                f" ({template_id})?"
-            ):
-                return
-            template = CLIENT.compute_client.update_compute_requirement_template(
-                compute_template
-            )
-            print_log(
-                f"Updated existing Compute Requirement Template '{template.name}'"
-                f" ({template.id})"
-            )
-            if ARGS_PARSER.quiet:
-                print(template.id)
+        return
+
+    # Update
+    compute_template.id = template_id
+    if not confirmed(
+        f"Update existing Compute Requirement Template '{name}'"
+        f" ({template_id})?"
+    ):
+        return
+    template = CLIENT.compute_client.update_compute_requirement_template(
+        compute_template
+    )
+    print_log(
+        f"Updated existing Compute Requirement Template '{template.name}'"
+        f" ({template.id})"
+    )
+    if ARGS_PARSER.quiet:
+        print(template.id)
 
 
 def create_keyring(resource: Dict, show_secrets: bool = False):
@@ -649,15 +650,14 @@ def create_allowance(resource: Dict):
         template_name_or_id = resource.get("requirementCreatedFromId", None)
         if template_name_or_id is not None:
             if "ydid:crt:" not in template_name_or_id:
-                template_ids = find_compute_requirement_template_ids_by_name(
+                template_id = find_compute_requirement_template_id_by_name(
                     client=CLIENT, name=template_name_or_id
                 )
-                if len(template_ids) == 0:
+                if template_id is None:
                     print_error(
                         f"Compute Requirement Template name '{template_name_or_id}' not found"
                     )
                     return
-                template_id = template_ids[0]
                 print_log(
                     f"Replaced Requirement Template name '{template_name_or_id}'"
                     f" with ID {template_id}"
@@ -796,7 +796,7 @@ def _get_model_class(class_name: str):
     return getattr(model, class_name)
 
 
-def create_attribute_definition_via_api(resource: Dict, resource_type: str):
+def create_attribute_definition(resource: Dict, resource_type: str):
     """
     Use the API to create/update user attribute definitions.
     """
@@ -812,21 +812,28 @@ def create_attribute_definition_via_api(resource: Dict, resource_type: str):
     headers = {"Authorization": f"yd-key {CONFIG_COMMON.key}:{CONFIG_COMMON.secret}"}
     if resource_type == RN_STRING_ATTRIBUTE_DEFINITION:
         payload = {
+            # Required
             "type": "co.yellowdog.platform.model.StringAttributeDefinition",
             "name": name,
             "title": title,
+            # Optional
             "description": resource.get("description"),
             "options": resource.get("options"),
         }
     else:  # RN_NUMERIC_ATTRIBUTE_DEFINITION
         payload = {
+            # Required
             "type": "co.yellowdog.platform.model.NumericAttributeDefinition",
             "name": name,
             "title": title,
             "defaultRankOrder": default_rank_order,
+            # Optional
             "description": resource.get("description"),
             "units": resource.get("units"),
+            # Note: Only one of 'range', 'options' can be supplied
+            # Allow the API to error-check
             "range": resource.get("range"),
+            "options": resource.get("options"),
         }
 
     # Attempt attribute creation
@@ -849,6 +856,45 @@ def create_attribute_definition_via_api(resource: Dict, resource_type: str):
     raise Exception(f"HTTP {response.status_code} ({response.text})")
 
 
+def create_namespace_policy(resource: Dict):
+    """
+    Create or update a namespace policy.
+    """
+    try:
+        namespace_policy = NamespacePolicy(
+            namespace=resource["namespace"],
+            autoscalingMaxNodes=resource.get("autoscalingMaxNodes"),
+        )
+    except KeyError as e:
+        raise Exception(f"Expected property to be defined ({e})")
+
+    # Test for existing policy
+    try:
+        CLIENT.namespaces_client.get_namespace_policy(
+            namespace=namespace_policy.namespace
+        )
+        if not confirmed(
+            f"Update existing Namespace Policy '{namespace_policy.namespace}'?"
+        ):
+            return
+    except Exception:
+        # Assume it's not found ... 404 from API
+        pass
+
+    try:
+        CLIENT.namespaces_client.save_namespace_policy(namespace_policy)
+    except Exception as e:
+        print_error(
+            f"Unable to create or update Namespace Policy for '{namespace_policy.namespace}': {e}"
+        )
+        return
+
+    print_log(
+        f"Created or updated  Namespace Policy '{namespace_policy.namespace}' with "
+        f"'autoscalingMaxNodes={namespace_policy.autoscalingMaxNodes}'"
+    )
+
+
 # Entry point
 if __name__ == "__main__":
     main()
